@@ -51,9 +51,8 @@ const unsigned int PLANE_EXPLODE_TIME = 2000;
 const unsigned int BOMB_EXPLODE_TIME = 1000;
 
 BomberBoard::BomberBoard(KGameRenderer *renderer, QGraphicsView *view, QObject *parent) :
-    QGraphicsScene(parent), m_renderer(renderer), m_view(view)
+    QGraphicsScene(parent), m_renderer(renderer), m_audioPlayer(nullptr), m_bomb(nullptr), m_view(view)
 {
-    m_bomb = Q_NULLPTR;
     m_clock = new QTimer(this);
     m_clock->setInterval(GAME_DELAY);
     connect(m_clock, &QTimer::timeout, this, &BomberBoard::tick);
@@ -64,8 +63,6 @@ BomberBoard::BomberBoard(KGameRenderer *renderer, QGraphicsView *view, QObject *
     resetPlane();
     clear();
 
-    m_audioPlayer = Q_NULLPTR;
-
     m_soundPath = QStandardPaths::locate(QStandardPaths::DataLocation, QLatin1Literal("sounds"), QStandardPaths::LocateDirectory);
 }
 
@@ -80,7 +77,7 @@ BomberBoard::~BomberBoard()
 
 void BomberBoard::resetPlane()
 {
-    m_plane->setState(Explodable::Moving);
+    m_plane->setState(Explodable::State::Moving);
     m_plane->resetPosition();
 }
 
@@ -98,7 +95,7 @@ void BomberBoard::resize(QSize &size)
     }
 
     m_plane->resize(m_tileSize);
-    if (m_bomb != Q_NULLPTR) {
+    if (m_bomb != nullptr) {
         m_bomb->resize(m_tileSize);
     }
 
@@ -111,7 +108,7 @@ void BomberBoard::resize(QSize &size)
 void BomberBoard::redraw()
 {
     m_plane->resetPixmaps();
-    if (m_bomb != Q_NULLPTR) {
+    if (m_bomb != nullptr) {
         m_bomb->resetPixmaps();
     }
 }
@@ -130,10 +127,10 @@ void BomberBoard::newLevel(unsigned int level)
 
     m_clock->stop();
     clear();
-    m_plane->setState(Explodable::Moving);
+    m_plane->setState(Explodable::State::Moving);
     m_buildingBlocks = 0;
     //Create the buildings
-    for (unsigned int i = 0; i < NUMBER_BUILDINGS; i++) {
+    for (unsigned int i = 0; i < NUMBER_BUILDINGS; ++i) {
         unsigned int min = level;
         if (min < 3) {
             min = 3;
@@ -175,7 +172,7 @@ void BomberBoard::playSound(const QString &name)
 void BomberBoard::setSounds(bool val)
 {
     m_playSounds = val;
-    if (val == true && m_audioPlayer == Q_NULLPTR) {
+    if (val == true && m_audioPlayer == nullptr) {
         m_audioPlayer = Phonon::createPlayer(Phonon::GameCategory);
     }
 }
@@ -186,7 +183,7 @@ void BomberBoard::tick()
 
     m_plane->advanceItem();
 
-    if (m_bomb != Q_NULLPTR) {
+    if (m_bomb != nullptr) {
         m_bomb->advanceItem();
     }
 
@@ -197,7 +194,7 @@ void BomberBoard::tick()
     // Draw everything
     m_plane->update();
 
-    if (m_bomb != Q_NULLPTR) {
+    if (m_bomb != nullptr) {
         m_bomb->update();
     }
 
@@ -208,7 +205,7 @@ void BomberBoard::tick()
 
 void BomberBoard::dropBomb()
 {
-    if (m_bomb == Q_NULLPTR && m_plane->state() == Explodable::Moving) {
+    if (m_bomb == nullptr && m_plane->state() == Explodable::State::Moving) {
         QPointF planePos = m_plane->position();
         m_bomb = new Bomb(m_renderer, this, planePos.x(), planePos.y() + 1, m_tileSize);
         this->addItem(m_bomb);
@@ -220,30 +217,30 @@ void BomberBoard::checkCollisions()
 {
     foreach (Building *building, m_buildings) {
         if (m_plane->nextBoundingRect().intersects(building->boundingRect()) && m_plane->state()
-                == Explodable::Moving) {
+                == Explodable::State::Moving) {
             // Plane crashed into the building
             building->destoryTop();
-            m_buildingBlocks--;
+            --m_buildingBlocks;
             crashed();
         }
 
-        if (m_bomb != Q_NULLPTR) {
+        if (m_bomb != nullptr) {
             if (m_bomb->nextBoundingRect().intersects(building->boundingRect()) && m_bomb->state()
-                    == Explodable::Moving) {
+                    == Explodable::State::Moving) {
                 // Bomb hit a building
                 building->destoryTop();
-                m_buildingBlocks--;
+                --m_buildingBlocks;
                 emit onBombHit();
                 bombHit(m_bomb, building->position().x(), Building::BUILD_BASE_LOCATION - (building->height()));
-                m_bomb = Q_NULLPTR;
+                m_bomb = nullptr;
             } else if (m_bomb->position().y() >= Building::BUILD_BASE_LOCATION + 1) {
                 // Bomb hit the ground
                 bombHit(m_bomb, (unsigned int)m_bomb->position().x(), Building::BUILD_BASE_LOCATION);
-                m_bomb = Q_NULLPTR;
+                m_bomb = nullptr;
             }
         }
 
-        if (m_plane->state() == Explodable::Moving && m_buildingBlocks == 0) {
+        if (m_plane->state() == Explodable::State::Moving && m_buildingBlocks == 0) {
             emit levelCleared();
         }
     }
@@ -251,9 +248,8 @@ void BomberBoard::checkCollisions()
 
 void BomberBoard::bombHit(Bomb *bomb, qreal moveBombToX, qreal moveBombToY)
 {
-    // playSound(QString("explode.ogg"));
     bomb->setPosition(moveBombToX, moveBombToY);
-    bomb->setState(Bomb::Exploding);
+    bomb->setState(Bomb::State::Exploding);
     m_explodingBombs.enqueue(bomb);
     QTimer::singleShot(BOMB_EXPLODE_TIME, this, SLOT(bombExploded()));
 }
@@ -274,7 +270,7 @@ void BomberBoard::settingsChanged()
 
 void BomberBoard::planeExploded()
 {
-    m_plane->setState(Plane::Exploded);
+    m_plane->setState(Plane::State::Exploded);
     emit onPlaneCrash();
 }
 
@@ -282,7 +278,7 @@ void BomberBoard::crashed()
 {
     QPointF pos = m_plane->position();
     m_plane->setPosition(pos.x() + 1, pos.y());
-    m_plane->setState(Plane::Exploding);
+    m_plane->setState(Plane::State::Exploding);
     playSound(QLatin1Literal("explode.ogg"));
     QTimer::singleShot(PLANE_EXPLODE_TIME, this, SLOT(planeExploded()));
 }
@@ -293,7 +289,7 @@ void BomberBoard::clear()
     m_buildings.clear();
 
     delete m_bomb;
-    m_bomb = Q_NULLPTR;
+    m_bomb = nullptr;
 
     resetPlane();
 }
